aboutsummaryrefslogtreecommitdiffstats
path: root/lib/base.php
diff options
context:
space:
mode:
authorThomas Pulzer <t.pulzer@kniel.de>2016-07-04 11:50:32 +0200
committerThomas Pulzer <t.pulzer@kniel.de>2016-07-04 11:50:32 +0200
commit90b7f74da714209ee9c6a9a3243dacbaee2dc435 (patch)
tree399f35c9ce80df45b39217f982535249aa3398ca /lib/base.php
parent978ab660f737edbc38e7847f86e6106fb456dcb7 (diff)
downloadnextcloud-server-90b7f74da714209ee9c6a9a3243dacbaee2dc435.tar.gz
nextcloud-server-90b7f74da714209ee9c6a9a3243dacbaee2dc435.zip
Changed name of default logfile from owncloud.log to nextcloud.log.
Diffstat (limited to 'lib/base.php')
-rw-r--r--lib/base.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/base.php b/lib/base.php
index 9e5304b1634..dde8e38218a 100644
--- a/lib/base.php
+++ b/lib/base.php
@@ -754,8 +754,8 @@ class OC {
$systemConfig = \OC::$server->getSystemConfig();
if ($systemConfig->getValue('installed', false) && $systemConfig->getValue('log_rotate_size', false) && !self::checkUpgrade(false)) {
//don't try to do this before we are properly setup
- //use custom logfile path if defined, otherwise use default of owncloud.log in data directory
- \OCP\BackgroundJob::registerJob('OC\Log\Rotate', $systemConfig->getValue('logfile', $systemConfig->getValue('datadirectory', OC::$SERVERROOT . '/data') . '/owncloud.log'));
+ //use custom logfile path if defined, otherwise use default of nextcloud.log in data directory
+ \OCP\BackgroundJob::registerJob('OC\Log\Rotate', $systemConfig->getValue('logfile', $systemConfig->getValue('datadirectory', OC::$SERVERROOT . '/data') . '/nextcloud.log'));
}
}